#!/usr/bin/env python

"""
  Author:  Yeison Cardona --<yeisoneng@gmail.com>
  Purpose:
  Created: 09/19/2017
"""

import time

import RPi.GPIO as GPIO
GPIO.setwarnings(False)
GPIO.setmode(GPIO.BCM)

#OUT = 23, 17, 27, 24
OUT = 23, 24, 17, 27
#OUT = 17, 27, 23, 24
#OUT = 23, 27, 24, 17
#OUT = 23, 17, 27, 3

[GPIO.setup(pin, GPIO.OUT, initial=GPIO.HIGH) for pin in OUT]



steps = (
    [False, True, True, False],
    [False, True, False, True],
    [True, False, False, True],
    [True, False, True, False],
)

STEP = 0

#----------------------------------------------------------------------
def step(s):
    """"""
    global STEP
    STEP += s

    if STEP > len(steps) - 1:
        STEP = 0
    elif STEP < 0:
        STEP = len(steps) - 1

    #print(STEP, steps[STEP])
    [GPIO.output(*out) for out in zip(OUT, steps[STEP])]
    time.sleep(10/1000)
    [GPIO.output(*out) for out in zip(OUT, [False, False, False, False])]


#----------------------------------------------------------------------
def cw():
    """"""
    step(1)


#----------------------------------------------------------------------
def ccw():
    """"""
    step(-1)





while True:
    cw()
    #time.sleep(10/1000)



#!/usr/bin/python3

from setuptools import setup, find_packages

setup(name = "underline.turntable",
      version = "0.3",
      description = "Speed and direction control of turntable.",

      author = "",
      author_email = "",
      maintainer = "Yeison Cardona",
      maintainer_email = "yeisoneng@gmail.com",

      url = "http://yeisoncardona.com",
      download_url = "",

      license = "GPLv3",
      keywords = "Raspberry Pi 3, Stepper motor",

      #list of classifiers in https://pypi.python.org/pypi?:action=list_classifiers
      classifiers=['Development Status :: 1 - Planning',
                   'Environment :: X11 Applications',
                   'Intended Audience :: Science/Research',
                   'License :: OSI Approved :: GNU Lesser General Public License v3 or later (LGPLv3+)',
                   'Programming Language :: Python :: 3 :: Only',
                   'Topic :: Scientific/Engineering',
                   'Topic :: Software Development :: Libraries :: Python Modules',
                   'Topic :: System :: Hardware',
                   ],

                   packages = find_packages(),
      include_package_data = True,

      install_requires = ['RPi.GPIO',
                          ],
      #scripts = [
          #"cmd/command",
                 #],

      zip_safe = False,

      )
